--
-- Shadow hardware management services startup script.
--


--
-- Load the public scripting interface as a Lua module.
--
node = require("node")

-- Replace the global print function with the node module system.print function.
-- Required.
print = node.system.print

-- Remove the manager instance from the global namespace. All client script
-- calls should go through the node module interface.
manager = nil

--
-- Disable any standard Lua functionality that has general read or write access
-- to the local file system.
--

-- Remove global functions that read from the local file system.
dofile = nil
loadfile = nil

-- Remove global modules that read from the local file system.
-- IO (Input and Output Facilities) module provides read and write file
-- access.
io = nil
module = nil
-- OS (Operating System Facilities) module provides file deletion and execute
-- access.
os = nil
package = nil
require = nil


--
-- Set the file search path for serving static files over the web server and
-- reading deployed system config siles.
--
node.system.set_search_path("static")

--
-- Set the log file name, but do not care if it fails. The initialization step
-- should define the site specific log name.
--
node.system.log("default/log.json")


--
-- Execute the external initialization script. If it does not exist, start up
-- the HTTP service so the user can fill in the preferences through the web
-- browser.
--
if not node.system.initialize() then
  -- Load the default database file if it is present. This is where we save
  -- user settings.
  if node.system.file_exists("default/database.db") then
    node.system.open_database("default/database.db")
  end

  local service = {["http"] = 32080}
  if not node.system.start_services(service) then
    node.system.quit()
  end

  -- Load the default location file.
  if node.system.file_exists(node._location_filename) then
    node.load_location(node._location_filename)
  end

  -- If we do not already have a valid location, make an initial guess based on
  -- our local IP address.
  preference = node.system.get_preference()
  if preference.location.active == 0 then
    node.system.geocode_address("")
  end

  -- We loaded a initialization file or successfully geocoded the address.
  -- Automatically save the preferences now.
  preference = node.system.get_preference()
  if preference.location.active ~= 0 then
    node.system.save_initialization()
  end
end

--
-- END bootstrap.lua
--
