--
-- api/geocode.lua
--
-- Return an string XML description of the current geographic location of this
-- software, based on user preferences. Same format as the online geocoder at:
--   
--   https://www.motionnode.com/geocode/
--

-- Utility function. Generate a location XML snippet based on input parameters.
local function location_node_to_xml(location)
  return
    "<location key=\"" .. node.xml.encode_attribute(location.key) ..
    "\" active=\"" .. node.xml.encode_attribute(location.active) .. "\">" ..
    "<name>" .. node.xml.encode_string(location.name) .. "</name>" ..
    "<address>" .. node.xml.encode_string(location.address) .. "</address>" ..
    "<point>" ..
    "<latitude>" .. node.xml.encode_string(location.latitude) .. 
    "</latitude>" ..
    "<longitude>" .. node.xml.encode_string(location.longitude) ..
    "</longitude>" ..
    "<elevation unit=\"meter\">" ..
    node.xml.encode_string(location.elevation) .. "</elevation>" ..
    "</point>" ..
    "</location>"
end

local result =
  "<?xml version=\"1.0\"?>" ..
  "<geocode>"

local list = node.system.get_location_list()
if list then
  local item
  for _,item in pairs(list) do
    result = result .. location_node_to_xml(item)
  end
else
  local preference = node.system.get_preference()
  if preference then
    result = result .. location_node_to_xml(preference.location)
  end
end

result = result .. "</geocode>"

return result
