--
-- api/node_to_mvc.lua
--
--   Output a Mokka Model Configuration File (MVC) based on the current
--   configuration in the Motion Service. This creates segment links for the
--   3D perspective view in Mokka. Since a C3D file has no joint hierarchy, this
--   helper file makes it easier to see the connections between the joint
--   positional markers.
--

local result =
  "<?xml version=\"1.0\"?>\n" ..
  "<MokkaModelVisualConfiguration name=\"ShadowMocap\" version=\"1.0\">\n"

local list = node.configuration()
if list then
  local item

  result = result .. "  <MarkersList>\n"
  for _, item in pairs(list) do
    result = result .. "    <Marker label=\"" .. item.id .. "\" radius=\"12\""

    if string.len(item.parent_id) == 0 then
      result = result .. " colorR=\"1\" colorG=\"1\" colorB=\"1\""
    elseif string.find(item.id, "^Left") then
      result = result .. " colorR=\"1\" colorG=\"0\" colorB=\"0\""
    elseif string.find(item.id, "^Right") then
      result = result .. " colorR=\"0\" colorG=\"1\" colorB=\"0\""
    else
      result = result .. " colorR=\"0\" colorG=\"1\" colorB=\"1\""
    end

    result = result .. " visible=\"1\" trajectory=\"0\"/>\n"
  end
  result = result .. "  </MarkersList>\n"

  result = result ..
    "  <SegmentsList>\n" ..
    "    <Segment label=\"Shadow\" colorR=\"0.819608\" colorG=\"1\"" ..
    " colorB=\"0.737255\" visible=\"1\" surface=\"0\"" ..
    " description=\"Full body skeleton model segments\">\n"

  for _, item in pairs(list) do
    if string.len(item.parent_id) ~= 0 then
      result = result .. "      <Point label=\"" .. item.id .. "\"/>\n"
    end
  end

  for _, item in pairs(list) do
    if string.len(item.parent_id) ~= 0 then
      result = result ..
        "      <Link pt1=\"" .. item.parent_id .. "\" pt2=\"" .. item.id ..
        "\"/>\n"
    end
  end

  result = result ..
    "    </Segment>\n" ..
    "  </SegmentsList>\n"

end

result = result .. "</MokkaModelVisualConfiguration>"

return result