--
-- Return an string XML description of the active ractor definition in the
-- Motion Service.
--
-- @file    api/ractor.lua
-- @version 4.0
--

local node_name = "ractor"

-- Utility function. Generate a location XML snippet based on input parameters.
local function ractor_node_to_xml(ractor)
  local result = "<definition"
  if ractor.key > 0 then
    result = result .. " key=\"" .. node.xml.encode_attribute(ractor.key) .. "\""
  end
  if ractor.active then
    result = result .. " active=\"" .. node.xml.encode_attribute(ractor.active) .. "\""
  end

  result = result .. ">"

  if ractor.name then
    result = result .. "<name>" .. node.xml.encode_string(ractor.name) .. "</name>"
  end

  result = result ..
    "<measurement unit=\"cm\">" ..
    "<height>" .. node.xml.encode_string(ractor.height) .. "</height>" ..
    "<arm>" .. node.xml.encode_string(ractor.arm) .. "</arm>" ..
    "<leg>" .. node.xml.encode_string(ractor.leg) .. "</leg>" ..
    "</measurement>"

  result = result .. "</definition>"

  return result
end

local result =
  "<?xml version=\"1.0\"?>" ..
  "<ractor>"

local list = node.system.get_ractor_list()
if list then
  local item
  for _,item in pairs(list) do
    result = result .. ractor_node_to_xml(item)
  end
else
  local preference = node.system.get_preference()
  if preference then
    result = result .. ractor_node_to_xml(preference.ractor)
  end
end

result = result .. "</ractor>"

return result
