--
-- Return a string JSON listing that defines properties that we want to display
-- in our live charting view.
--
-- @file    json/chart.lua
-- @version 4.0
--
local state = {
  ['type'] = 'chart',
  ['items'] = {},
  ['rate'] = {
    {['key'] = 1, ['id'] = '1', ['num_frame'] = 100, ['name'] = '1'},
    {['key'] = 5, ['id'] = '5', ['num_frame'] = 500, ['name'] = '5'},
    {['key'] = 10, ['id'] = '10', ['num_frame'] = 1000, ['name'] = '10'},
    {['key'] = 20, ['id'] = '20', ['num_frame'] = 2000, ['name'] = '20'},
    {['key'] = 30, ['id'] = '30', ['num_frame'] = 3000, ['name'] = '30'}
  },
  ['time_step'] = 0.01,
  ['channel'] = {
    {
      ['id'] = 'Gq',
      ['name'] = 'Global Quaternion',
      ['name_compact'] = 'Quat',
      ['unit'] = '1 unit',
      ['info'] = 'Quaternion of unit length that represents the spatial orientation of this device in global space. Relative to Earth\'s magnetic field and gravity',
      ['dim'] = 4
    },
    {
      ['id'] = 'Gdq',
      ['name'] = 'Global Delta Quaternion',
      ['name_compact'] = 'Delta Quat',
      ['unit'] = '1 unit',
      ['info'] = 'Quaternion that defines the angular rate of this device in global space. First derivative of the Gq global quaternion',
      ['dim'] = 4
    },
    {
      ['id'] = 'Lq',
      ['name'] = 'Local Quaternion',
      ['name_compact'] = 'Local Quat',
      ['unit'] = '1 unit',
      ['info'] = 'Quaternion of unit length that represents the rotation of this joint segment relative to its parent joint segment',
      ['dim'] = 4
    },
    {
      ['id'] = 'r',
      ['name'] = 'Local Euler Angles',
      ['name_compact'] = 'Local Euler',
      ['unit'] = 'π radians',
      ['scale'] = 1.0 / 3.14159,
      ['dim'] = 3
    },
    {
      ['id'] = 'la',
      ['name'] = 'Linear Acceleration',
      ['name_compact'] = 'Linacc',
      ['unit'] = '1 g',
      ['info'] = 'Acceleration due to linear motion, 1 g = 980.665 cm/s²',
      ['dim'] = 3
    },
    --[[
    {
      ['id'] = 'lv',
      ['name'] = 'Linear Velocity',
      ['name_compact'] = 'Vel',
      ['unit'] = '100 cm/s',
      ['info'] = 'Velocity due to linear motion in centimeters per second',
      ['scale'] = 0.01,
      ['dim'] = 3
    },
    ]]--
    {
      ['id'] = 'lt',
      ['name'] = 'Position',
      ['name_compact'] = 'Pos',
      ['unit'] = '100 cm',
      ['info'] = 'Position in centimeters',
      ['scale'] = 0.01,
      ['dim'] = 3
    },
    {
      ['id'] = 'c',
      ['name'] = 'Constraint Position',
      ['name_compact'] = 'Cons',
      ['unit'] = '100 cm',
      ['info'] = 'Position in centimeters',
      ['scale'] = 0.01,
      ['dim'] = 4
    },
    {
      ['id'] = 'a',
      ['name'] = 'Accelerometer',
      ['name_compact'] = 'Accel',
      ['unit'] = '1 g',
      ['info'] = 'Standard acceleration due to gravity at Earth\'s surface, 1 g = 980.665 cm/s²',
      ['dim'] = 3
    },
    {
      ['id'] = 'm',
      ['name'] = 'Magnetometer',
      ['name_compact'] = 'Mag',
      ['unit'] = '50 µT',
      ['info'] = 'Magnetic flux in microtesla, 100 µT = 1 Guass. The magnitude of Earth\'s magnetic field varies from 25 to 65 µT',
      ['dim'] = 3,
      ['scale'] = 0.02
    },
    {
      ['id'] = 'g',
      ['name'] = 'Gyroscope',
      ['name_compact'] = 'Gyro',
      ['unit'] = '500 °/s',
      ['info'] = 'Angular velocity in degrees per second',
      ['dim'] = 3,
      ['scale'] = 0.002
    },
    --[[
    {
      ['id'] = 'temp',
      ['name'] = 'Temperature',
      ['name_compact'] = 'Temp',
      ['unit'] = '50 °C',
      ['info'] = 'Temperature onboard this device in degrees Celsius',
      ['dim'] = 1,
      ['scale'] = 0.02
    },
    ]]--
    {
      ['id'] = 'A',
      ['name'] = 'Raw Accelerometer',
      ['name_compact'] = 'Raw Accel',
      ['unit'] = '4096 unit',
      ['info'] = 'Uncalibrated raw measurement from the accelerometer on this device',
      ['dim'] = 3,
      ['scale'] = 1 / 4096
    },
    {
      ['id'] = 'M',
      ['name'] = 'Raw Magnetometer',
      ['name_compact'] = 'Raw Mag',
      ['unit'] = '4096 unit',
      ['info'] = 'Uncalibrated raw measurement from the magnetometer on this device',
      ['dim'] = 3,
      ['scale'] = 1 / 4096
    },
    {
      ['id'] = 'G',
      ['name'] = 'Raw Gyroscope',
      ['name_compact'] = 'Raw Gyro',
      ['unit'] = '4096 unit',
      ['info'] = 'Uncalibrated raw measurement from the gyroscope on this device',
      ['dim'] = 3,
      ['scale'] = 1 / 4096
    },
    --[[
    {
      ['id'] = 'Temp',
      ['name'] = 'Raw Temperature',
      ['name_compact'] = 'Raw Temp',
      ['unit'] = '4096 unit',
      ['info'] = 'Uncalibrated raw measurement from the temperature sensor on this device',
      ['dim'] = 1,
      ['scale'] = 1 / 4096
    },
    ]]--
    {
      ['id'] = 'dt',
      ['name'] = 'Timestep',
      ['name_compact'] = 'Timestep',
      ['unit'] = '1 sec',
      ['info'] = 'Time in seconds between each measurement frame',
      ['dim'] = 1
    },
    {
      ['id'] = 'timestamp',
      ['name'] = 'Timestamp',
      ['name_compact'] = 'Timestamp',
      ['unit'] = '10 seconds',
      ['info'] = 'Device clock time in seconds since this device started its measurements',
      ['dim'] = 1,
      ['scale'] = 0.1
    },
    {
      ['id'] = 'systemtime',
      ['name'] = 'System Timestamp',
      ['name_compact'] = 'Sys Time',
      ['unit'] = '1 unit',
      ['info'] = 'System clock time in seconds since this device started its measurements',
      ['dim'] = 1,
      ['scale'] = 0.1
    },
    {
      ['id'] = 'ea',
      ['name'] = 'Error Accelerometer',
      ['name_compact'] = 'Err Acc',
      ['unit'] = '1 unit',
      ['info'] = 'Estimated measurement error from the accelerometer sensor',
      ['dim'] = 1
    },
    {
      ['id'] = 'em',
      ['name'] = 'Error Magnetometer',
      ['name_compact'] = 'Err Mag',
      ['unit'] = '1 unit',
      ['info'] = 'Estimated measurement error from the magnetometer sensor',
      ['dim'] = 1
    },
    {
      ['id'] = 'eg',
      ['name'] = 'Error Gyroscope',
      ['name_compact'] = 'Err Gyro',
      ['unit'] = '1 unit',
      ['info'] = 'Estimated measurement error from the gyroscope sensor',
      ['dim'] = 1
    },
    {
      ['id'] = 'ec',
      ['name'] = 'Error Constraint',
      ['name_compact'] = 'Err Cons',
      ['unit'] = '1 unit',
      ['info'] = 'Estimated measurement error in this positional constraint',
      ['dim'] = 1
    },
    {
      ['id'] = 'p',
      ['name'] = 'Pressure',
      ['name_compact'] = 'Pressure',
      ['unit'] = '1 unit',
      ['info'] = 'Unitless measurements of the footstep force for this insole. Heel and toe force resistive sensor measurements',
      ['dim'] = 4
    },
    --[[
    {
      ['id'] = 'atm',
      ['name'] = 'Atmospheric Pressure',
      ['name_compact'] = 'Atmos',
      ['unit'] = '1000 mbar',
      ['dim'] = 1
    },
    {
      ['id'] = 'elev',
      ['name'] = 'Elevation',
      ['name_compact'] = 'Elev',
      ['unit'] = 'meters',
      ['dim'] = 1
    },
    ]]--
    {
      ['id'] = 'Bq',
      ['name'] = 'Body Quaternion',
      ['name_compact'] = 'Body Quat',
      ['unit'] = '1 unit',
      ['info'] = 'Quaternion of unit length that represents the rotation of this joint segment relative to the Shadow skeleton',
      ['dim'] = 4
    }
  }
}

local _node_to_json = function(item)
  return {
    ['key'] = item.key,
    ['id'] = item.id,
    ['name'] = item.name,
    ['active'] = (item.active and not item.bus)
  }
end

local list = node.configuration()
if list then
  local max_time_step = 0

  local item
  for _,item in pairs(list) do
    table.insert(state.items, _node_to_json(item))

    if item.time_step > max_time_step then
      max_time_step = item.time_step
    end
  end

  if not(state.time_step == max_time_step) then
    for _,item in pairs(state.rate) do
      item.num_frame = math.floor(
        item.num_frame * (state.time_step / max_time_step) + 0.5)
    end
    state.time_step = max_time_step
  end
end

return node.json.encode(state)
