--
-- Return a string JSON listing of all command in the public Lua scripting
-- interface to the Motion Service. Can be use as a autocomplete or hint for
-- a console application and for unit testing.
--
-- @file    json/console.lua
-- @version 4.0
--
local tbl_list = {
  ['node.'] = node,
  ['node.system.'] = node.system
}

local cmd_blacklist = {
  ['node.system.initialize'] = true,
  ['node.system.is_initialized'] = true,
  ['node.system.log'] = true,
  ['node.system.print'] = true,
  ['node.system.start_services'] = true
}

local items_table = {}

local prefix, tbl
for prefix,tbl in pairs(tbl_list) do
  local key, value
  for key,value in pairs(tbl) do
    if type(value) == "function" then
      local cmd = prefix .. key
      if string.find(key, "_") ~= 0 and not cmd_blacklist[cmd] then
        table.insert(items_table, cmd)
      end
    end
  end
end

table.sort(items_table)

return node.json.encode({
  ['type'] = 'console',
  ['items'] = items_table
})
