--
-- Return a string JSON listing of all available hardware related settings for
-- a single device in the configuration. Different hardware types and versions
-- support different measurement ranges and sample rates.
--
-- @file    json/device_settings.lua
-- @version 4.0
--
local base = _G

local item = nil
if HTTP_REQUEST and HTTP_REQUEST.id then
  item = node.get_node_by_id(HTTP_REQUEST.id)
end

local state = {
  ['type'] = 'device_settings',
  ['defaults'] = {
    ['gselect'] = 2,
    ['time_step'] = 0.01,
    ['gain'] = 0.5,
    ['gain_sensor'] = 1,
    ['track_gyroscope_bias'] = 1,
    ['pipeline_select'] = 0
  },
  ['gselect'] = {
    {['key'] = 2, ['name'] = '2'},
    {['key'] = 4, ['name'] = '4'},
    {['key'] = 6, ['name'] = '6'},
    {['key'] = 8, ['name'] = '8'},
    {['key'] = 16, ['name'] = '16'}
  },
  ['pipeline_select'] = {
    {['key'] = 0, ['name'] = 'All'},
    {['key'] = 1, ['name'] = 'Accel'},
    {['key'] = 5, ['name'] = 'Accel-Gyro'},
    {['key'] = 3, ['name'] = 'Accel-Mag'},
    {['key'] = 4, ['name'] = 'Gyro'},
    {['key'] = -1, ['name'] = 'None'}
  },
  ['sample_rate'] = {
    {['key'] = 50, ['name'] = '50'},
    {['key'] = 100, ['name'] = '100'},
    {['key'] = 200, ['name'] = '200'},
    {['key'] = 400, ['name'] = '400'},
    {['key'] = 500, ['name'] = '500'},
    {['key'] = 800, ['name'] = '800'},
    {['key'] = 1000, ['name'] = '1000'}
  },
  ['node'] = item
}

return node.json.encode(state)
