--
-- Return a string JSON description of the current configuration list of the
-- Motion Service. Show all hardware devices that are available and their
-- current status.
--
-- @file    json/devices.lua
-- @version 4.0
--
local is_taking = node.is_taking()
local is_reading = is_taking or node.is_reading()
local is_connected = is_reading or node.is_connected()
local is_configured = is_connected or node.is_configured()
local is_tracking = node.is_tracking()

local state = {
  ['type'] = 'devices',
  ['items'] = {},
  ['is_configured'] = is_configured,
  ['is_connected'] = is_connected,
  ['is_reading'] = is_reading,
  ['is_taking'] = is_taking,
  ['is_tracking'] = is_tracking
}

local _node_to_json = function(item, default_node, is_connected, is_reading, detail)
  local show_detail = false
  if detail and item.id == detail then
    show_detail = true
  end

  local state = {
    ['key'] = item.key,
    ['id'] = item.id,
    ['name'] = item.name,
    ['source'] = item.source,
    ['gain'] = item.gain,
    ['gain_sensor'] = item.gain_sensor,
    ['gselect'] = item.gselect,
    ['time_step'] = item.time_step,
    ['track_gyroscope_bias'] = item.track_gyroscope_bias,
    ['pipeline_select'] = item.pipeline_select,
    ['auth'] = item.auth,
    ['is_connected'] = is_connected or node.is_connected(item.id),
    ['is_reading'] = is_reading or node.is_reading(item.id),
    ['items'] = {}
  }

  local optional = {
    'active',
    'bus',
    'delay',
    'flags',
    'node_version',
    'parent',
    'pipeline_select',
    'sample_rate',
    'uuid'
  }

  for _,field in pairs(optional) do
    if show_detail or item[field] ~= default_node[field] then
      state[field] = item[field]
    end
  end

  return state
end

--
-- Node list.
--
local list = node.configuration()
if list then
  local default_node = node.get_node_default()

  local item
  for _,item in pairs(list) do
    local item_state = _node_to_json(
      item, default_node, is_connected, is_reading, node_detail)
    if item_state then
      table.insert(state.items, item_state)
    end
  end
end

return node.json.encode(state)
