--
-- Return a string JSON description of the current connection state of the
-- Motion Service.
--
-- @file    json/state.lua
-- @version 4.0
--

local is_taking = node.is_taking()
local is_reading = is_taking or node.is_reading()
local is_connected = is_reading or node.is_connected()
local is_configured = is_connected or node.is_configured()
local is_tracking = node.is_tracking()

local state = {
  ['type'] = 'state',
  ['is_configured'] = is_configured,
  ['is_connected'] = is_connected,
  ['is_reading'] = is_reading,
  ['is_taking'] = is_taking,
  ['is_tracking'] = is_tracking,
  ['status'] = 'Unknown device status',
  ['status_compact'] = 'Unknown status',
  ['pipeline_select'] = 0,
  ['inertial'] = false
}

--
-- Status message. Like the Motion Monitor tray notification.
--
if not is_configured then
  state.status = "Empty configuration, 0 devices available"
  state.status_compact = "0 devices"
else
  local num_node = 0

  if is_taking then
    state.status = "Recording from "
    state.status_compact = " recording"
    num_node = node.num_reading(true)
  elseif is_reading then
    state.status = "Reading from "
    state.status_compact = " reading"
    num_node = node.num_reading(true)
  else
    state.status = "Connected to "
    state.status_compact = " connected"
    num_node = node.num_connected(true)
  end

  local device = " device"
  if 1 ~= num_node then
    device = device .. "s"
  end

  state.status = state.status .. num_node .. device
  state.status_compact = num_node .. device .. state.status_compact

  state.pipeline_select = node.ui.get_pipeline_select()
  state.inertial = (state.pipeline_select == 5)
end

local take = node.get_take()
if take then
  state['take'] = {
    ['name'] = take.name,
    ['description'] = take.description,
    ['loaded_from'] = take.loaded_from
  }
end

return node.json.encode(state)
