--
-- Return a string list of the available views. Order them how we
-- want them presented and put them into related groups.
--
-- @file    json/views.lua
-- @version 4.0
--

local Measurement = 1 << 15
local MeasurementRaw = Measurement | 1 << 16

local views = {
  ['type'] = 'views',
  ['version'] = node.get_version(),
  ['is_initialized'] = node.system.is_initialized(),
  ['items'] = {}
}

if views.is_initialized then
  local show_shadow = 1
  local show_motion = 0

  if not views.version.is_shadow then
    show_shadow = 0
    show_motion = 1
  end

  local viewer_table = {
    {
      ['name'] = 'viewer',
      ['title'] = '3D Viewer',
      ['icon'] = '3d_rotation',
      ['show'] = show_shadow
    },
    {
      ['name'] = 'node',
      ['title'] = 'Node Viewer',
      ['icon'] = '3d_rotation',
      ['show'] = show_motion
    },
    {
      ['name'] = 'devices',
      ['title'] = 'Devices',
      ['icon'] = 'device_hub'
    }
  }

  if views.version.capability_mask & MeasurementRaw ~= 0 then
    table.insert(viewer_table, {
      ['name'] ='chart',
      ['title'] = 'Chart',
      ['icon'] = 'show_chart'
    })
  else
    table.insert(viewer_table, {
      ['name'] ='chart',
      ['title'] = 'Chart',
      ['icon'] = 'show_chart',
      ['show'] = 0
    })
  end

  table.insert(views.items, viewer_table)

  table.insert(views.items, {
    {
      ['name'] = 'location',
      ['title'] = 'Location',
      ['icon'] = 'near_me'
    },
    {
      ['name'] = 'log',
      ['title'] = 'Log',
      ['icon'] = 'list'
    },
    {
      ['name'] = 'console',
      ['title'] = 'Console',
      ['icon'] = 'code'
    },
  })

  table.insert(views.items, {
    {
      ['name'] = 'settings',
      ['title'] = 'Settings',
      ['icon'] = 'settings'
    },
    {
      ['name'] = 'help',
      ['title'] = 'Help',
      ['icon'] = 'help'
    },
    {
      ['name'] = 'calibrate',
      ['title'] = 'Calibrate',
      ['icon'] = 'builder',
      ['show'] = 0
    },
    {
      ['name'] = 'error',
      ['title'] = 'Error',
      ['icon'] = 'error',
      ['show'] = 0
    },
    {
      ['name'] = 'system',
      ['title'] = 'System',
      ['icon'] = 'view_list',
      ['show'] = 0
    },
    {
      ['name'] = 'test',
      ['title'] = 'Test',
      ['icon'] = 'test',
      ['show'] = 0
    }
  })
else
  table.insert(views.items, {
    {
      ['name'] = 'setup',
      ['title'] = 'Setup',
      ['icon'] = 'settings_applications',
      ['show'] = 1
    },
    {
      ['name'] = 'log',
      ['title'] = 'Log',
      ['icon'] = 'list'
    }
  })
end

return node.json.encode(views)
